==> rogo-7.3.0.tar.gz: lang/en/question/edit/likert_scales.php <==
<?php

// This file is part of Rogō
//
// Rogō is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Rogō is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Rogō.  If not, see <http://www.gnu.org/licenses/>.

// Likert Scales data - this is how the settings are saved, separate columns with vertical bars (<br /> tages can be used for break lines)
$string['failpass3'] = 'Fail|Borderline|Pass';
$string['lowhigh3'] = 'Low||High';
$string['lowhigh4'] = 'Low|||High';
$string['lowhigh5'] = 'Low||||High';
$string['neveralways3'] = 'Never||Always';
$string['neveralways4'] = 'Never|||Always';
$string['neveralways5'] = 'Never||||Always';
$string['disagre3'] = 'Disagree|Neutral|Agree';
$string['disagre4'] = 'Strongly<br />Disagree|Disagree|Agree|Strongly<br />Agree';
$string['disagre5a'] = 'Strongly<br />Disagree|Disagree|Neither Disagree<br />nor Agree|Agree|Strongly<br />Agree';
$string['disagre5b'] = 'Strongly<br />Disagree|Disagree|Uncertain|Agree|Strongly<br />Agree';
$string['disagre5c'] = 'Strongly<br />Disagree|Disagree|Neutral|Agree|Strongly<br />Agree';
// Likert Scales
$string['failpass'] = 'Fail, Borderline, Pass';
$string['lowhigh'] = 'Low to High';
$string['neveralways'] = 'Never to Always';
$string['disagre3point'] = 'Disagree, Neutral, Agree';
$string['disagre4point'] = 'Strongly Disagree, Disagree, Agree, Strongly Agree';
$string['disagre5pointneither'] = 'Strongly Disagree, Disagree, Neither Disagree nor Agree, Agree, Strongly Agree';
$string['disagre5pointuncertain'] = 'Strongly Disagree, Disagree, Uncertain, Agree, Strongly Agree';
$string['disagre5pointneutral'] = 'Strongly Disagree, Disagree, Neutral, Agree, Strongly Agree';
$string['custom'] = 'Custom';
$string['na_abstain'] = 'N/A|Abstain|Not Applicable';
// QMP for QTI import
$string['qmpagree3'] = 'Agree|Neither Agree nor Disagree|Disagree';
$string['qmplike3'] = 'I like this|Neutral|I don\'t like this';
$string['qmplikeme3'] = 'Like me|Neutral|Not like me';
$string['qmpsatisfied3'] = 'Satisfied|Neutral|Dissatisfied';
$string['qmpagree4'] = 'Strongly Agree|Agree|Disagree|Stongly Disagree';
$string['qmplike4'] = 'I like this a lot|I like this|I don\'t like this|I don\'t like this a lot';
$string['qmplikeme4'] = 'Very Like me|Like me|Not like me|Very Not like me';
$string['qmpsatisfied4'] = 'Very Satisfied|Satisfied|Dissatisfied|Very Dissatisfied';
$string['qmpagree5'] = 'Strongly Agree|Agree|Neither Agree nor Disagree|Disagree|Stongly Disagree';
$string['qmplike5'] = 'I like this a lot|I like this|Neutral|I don\'t like this|I don\'t like this a lot';
$string['qmplikeme5'] = 'Very Like me|Like me|Neutral|Not like me|Very Not like me';
$string['qmpsatisfied5'] = 'Very Satisfied|Satisfied|Neutral|Dissatisfied|Very Dissatisfied';
// True/false (OK, not strictly likert scale)
$string['qmptf'] = 'True|False';
$string['qmpyn'] = 'Yes|No';

==> rogo-7.4.2.tar.gz: lang/en/question/edit/likert_scales.php <==
<?php

// This file is part of Rogō
//
// Rogō is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Rogō is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Rogō.  If not, see <http://www.gnu.org/licenses/>.

// Likert Scales data - this is how the settings are saved, separate columns with vertical bars)
$string['failpass3'] = 'Fail|Borderline|Pass';
$string['lowhigh3'] = 'Low|Medium|High';
$string['lowhigh4'] = 'Low|Tending Low|Tending High|High';
$string['lowhigh5'] = 'Low|Tending Low|Medium|Tending High|High';
$string['neveralways3'] = 'Never|Sometimes|Always';
$string['neveralways4'] = 'Never|Hardly|Sometimes|Always';
$string['neveralways5'] = 'Never|Hardly|Occasionally|Sometimes|Always';
$string['disagre3'] = 'Disagree|Neutral|Agree';
$string['disagre4'] = 'Strongly Disagree|Disagree|Agree|Strongly Agree';
$string['disagre5a'] = 'Strongly Disagree|Disagree|Neither Disagree nor Agree|Agree|Strongly Agree';
$string['disagre5b'] = 'Strongly Disagree|Disagree|Uncertain|Agree|Strongly Agree';
$string['disagre5c'] = 'Strongly Disagree|Disagree|Neutral|Agree|Strongly Agree';
// Likert Scales
$string['failpass'] = 'Fail, Borderline, Pass';
$string['lowhigh'] = 'Low to High';
$string['neveralways'] = 'Never to Always';
$string['disagre3point'] = 'Disagree, Neutral, Agree';
$string['disagre4point'] = 'Strongly Disagree, Disagree, Agree, Strongly Agree';
$string['disagre5pointneither'] = 'Strongly Disagree, Disagree, Neither Disagree nor Agree, Agree, Strongly Agree';
$string['disagre5pointuncertain'] = 'Strongly Disagree, Disagree, Uncertain, Agree, Strongly Agree';
$string['disagre5pointneutral'] = 'Strongly Disagree, Disagree, Neutral, Agree, Strongly Agree';
$string['custom'] = 'Custom';
$string['na_abstain'] = 'N/A|Abstain|Not Applicable';
// QMP for QTI import
$string['qmpagree3'] = 'Agree|Neither Agree nor Disagree|Disagree';
$string['qmplike3'] = 'I like this|Neutral|I don\'t like this';
$string['qmplikeme3'] = 'Like me|Neutral|Not like me';
$string['qmpsatisfied3'] = 'Satisfied|Neutral|Dissatisfied';
$string['qmpagree4'] = 'Strongly Agree|Agree|Disagree|Stongly Disagree';
$string['qmplike4'] = 'I like this a lot|I like this|I don\'t like this|I don\'t like this a lot';
$string['qmplikeme4'] = 'Very Like me|Like me|Not like me|Very Not like me';
$string['qmpsatisfied4'] = 'Very Satisfied|Satisfied|Dissatisfied|Very Dissatisfied';
$string['qmpagree5'] = 'Strongly Agree|Agree|Neither Agree nor Disagree|Disagree|Stongly Disagree';
$string['qmplike5'] = 'I like this a lot|I like this|Neutral|I don\'t like this|I don\'t like this a lot';
$string['qmplikeme5'] = 'Very Like me|Like me|Neutral|Not like me|Very Not like me';
$string['qmpsatisfied5'] = 'Very Satisfied|Satisfied|Neutral|Dissatisfied|Very Dissatisfied';
// True/false (OK, not strictly likert scale)
$string['qmptf'] = 'True|False';
$string['qmpyn'] = 'Yes|No';
